#!/usr/bin/python2.5
import sys
from PyQt4 import QtGui,QtCore
from PyQt4.phonon import Phonon
from simpsons import *

class MyForm(QtGui.QMainWindow):
        def __init__(self, parent=None):
                #build parent user interface
                QtGui.QWidget.__init__(self, parent)
                self.ui = Ui_MainWindow()
                self.ui.setupUi(self)
                self.ui.soundList.setCurrentRow(0)
                self.m_media = Phonon.MediaObject(self)
                audioOutput = Phonon.AudioOutput(Phonon.MusicCategory, self)
                audioOutput.setVolume(0.3)
                Phonon.createPath(self.m_media, audioOutput)
                #connect buttons
                QtCore.QObject.connect(self.ui.pushButton, QtCore.SIGNAL('clicked()'), self.playFart)
                
                self.farts={
                        "One Day":"/opt/Simpsons/sounds/a.wav", "Dollor":"/opt/Simpsons/sounds/b.wav",
                        "Blackhole":"/opt/Simpsons/sounds/c.wav", "Brain":"/opt/Simpsons/sounds/d.wav",
                        "Candy":"/opt/Simpsons/sounds/e.wav", "No Tv":"/opt/Simpsons/sounds/f.wav", 
                        "Da Da Da Da":"/opt/Simpsons/sounds/g.wav", "Evil Homer":"/opt/Simpsons/sounds/h.wav", 
                        "Free":"/opt/Simpsons/sounds/i.wav", "Crap":"/opt/Simpsons/sounds/j.wav",
			   "Mr Burns":"/opt/Simpsons/sounds/k.wav", "Smart":"/opt/Simpsons/sounds/l.wav",
                        "Ohcrap":"/opt/Simpsons/sounds/m.wav", "Whisky":"/opt/Simpsons/sounds/n.wav", 
                        "WooHo":"/opt/Simpsons/sounds/o.wav"
                        }
                
        def playFart(self):
                fart=self.farts[str(self.ui.soundList.currentItem().text())]
                self.m_media.setCurrentSource(Phonon.MediaSource(fart))
                self.m_media.play()
                        

if __name__ == "__main__":
        app = QtGui.QApplication(sys.argv)
        myapp = MyForm()
        myapp.show()
        sys.exit(app.exec_())